@@ -54,7 +54,7 @@ static char  *license_msg[] = {
  */
 
 #ifdef RCSID
-static char rcsid[] = "$Id: gzip.c,v 1.8 2006/12/07 06:58:13 eggert Exp $";
+static char rcsid[] = "$Id: gzip.c,v 1.9 2006/12/09 01:19:52 eggert Exp $";
 #endif
 
 #include <config.h>
@@ -85,10 +85,6 @@ static char rcsid[] = "$Id: gzip.c,v 1.8 2006/12/07 06:58:13 eggert Exp $";
 #  include <fcntl.h>
 #endif
 
-#ifdef HAVE_LIMITS_H
-#  include <limits.h>
-#endif
-
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
@@ -539,6 +535,7 @@ int main (argc, argv)
     ALLOC(ush, tab_prefix1, 1L<<(BITS-1));
 #endif
 
+    exiting_signal = quiet ? SIGPIPE : 0;
     install_signal_handlers ();
 
     /* And get to work */
@@ -1780,8 +1777,6 @@ install_signal_handlers ()
   int nsigs = sizeof sig / sizeof sig[0];
   int i;
 
-  exiting_signal = quiet ? SIGPIPE : 0;
-
 #if SA_NOCLDSTOP
   struct sigaction act;
 
