@@ -1,6 +1,7 @@
 /* util.c -- utility functions for gzip support
 
-   Copyright (C) 1997, 1998, 1999, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1997, 1998, 1999, 2001, 2002, 2006 Free Software
+   Foundation, Inc.
    Copyright (C) 1992-1993 Jean-loup Gailly
 
    This program is free software; you can redistribute it and/or modify
@@ -18,7 +19,7 @@
    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
 
 #ifdef RCSID
-static char rcsid[] = "$Id: util.c,v 1.4 2006/11/20 08:40:34 eggert Exp $";
+static char rcsid[] = "$Id: util.c,v 1.5 2006/12/09 01:19:53 eggert Exp $";
 #endif
 
 #include <config.h>
@@ -27,9 +28,6 @@ static char rcsid[] = "$Id: util.c,v 1.4 2006/11/20 08:40:34 eggert Exp $";
 
 #include "tailor.h"
 
-#ifdef HAVE_LIMITS_H
-#  include <limits.h>
-#endif
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
